/*
 *   IRC - Internet Relay Chat, src/modules/m_tkl_export.c
 *   (C) 2001 The UnrealIRCd Team
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers.
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include "config.h"
#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include <time.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef _WIN32
#include <io.h>
#endif
#include <fcntl.h>
#include "h.h"
#ifdef _WIN32
#include "version.h"
#endif

DLLFUNC int m_TKLEXPORT(aClient *cptr, aClient *sptr, int parc, char *parv[]);
aTKline *tklines[TKLISTLEN];

#define MSG_TKLEXPORT 	"TKLEXPORT"	

ModuleHeader MOD_HEADER(m_tkl_export)
  = {
	"tklexport",
	"$Id: m_tkl_export.c,v 2.0 2003/11/27 Certus Exp $",
	"command /tklexport",
	"3.2-b8-1",
	NULL 
    };

DLLFUNC int MOD_INIT(m_tkl_export)(ModuleInfo *modinfo)
{
	CommandAdd(modinfo->handle, MSG_TKLEXPORT, NULL, m_TKLEXPORT, MAXPARA, 0);
	return MOD_SUCCESS;
}

DLLFUNC int MOD_LOAD(m_tkl_export)(int module_load)
{
	return MOD_SUCCESS;
}

DLLFUNC int MOD_UNLOAD(m_tkl_export)(int module_unload)
{
	return MOD_SUCCESS;
}

int m_TKLEXPORT(aClient *cptr, aClient *sptr, int parc, char *parv[])
{
	aTKline *tk;
	int index;
	char filename[25] = "tkl_export_file.bak";
    FILE *fptr;

	if (!IsNetAdmin(cptr)) {
		sendto_one(cptr, err_str(ERR_NOPRIVILEGES), me.name, cptr->name);
		return 0;
	}

	fptr = fopen(filename, "w");

    if(fptr == NULL)
     {
		  sendto_realops("Error while opening file %s.", filename);
          return 0;
     }

	tkl_check_expire(NULL);
	sendnotice(sptr, "Exporting TKLs......");
	for (index = 0; index < TKLISTLEN; index++)
	 for (tk = tklines[index]; tk; tk = tk->next)
	 {
		if (tk->type == (TKL_KILL | TKL_GLOBAL))
		{
			fprintf(fptr, "%c %s@%s %li %li %s :%s\n", 'G', tk->usermask, tk->hostmask, tk->expire_at, tk->set_at, tk->setby, tk->reason);
		}
		if (tk->type == (TKL_ZAP | TKL_GLOBAL))
		{
			fprintf(fptr, "%c %s@%s %li %li %s :%s\n", 'Z', tk->usermask, tk->hostmask, tk->expire_at, tk->set_at, tk->setby, tk->reason);
		}
		if (tk->type == (TKL_SHUN | TKL_GLOBAL))
		{
			fprintf(fptr, "%c %s@%s %li %li %s :%s\n", 's', tk->usermask, tk->hostmask, tk->expire_at, tk->set_at, tk->setby, tk->reason);
		}
		if (tk->type == (TKL_KILL))
		{
			fprintf(fptr, "%c %s@%s %li %li %s :%s\n", 'K', tk->usermask, tk->hostmask, tk->expire_at, tk->set_at, tk->setby, tk->reason);
		}
		if (tk->type == (TKL_ZAP))
		{
			fprintf(fptr, "%c %s@%s %li %li %s :%s\n", 'z', tk->usermask, tk->hostmask, tk->expire_at, tk->set_at, tk->setby, tk->reason);
		}
	}
    fclose(fptr);
	sendnotice(sptr, "All TKLs have been exported to file %s", filename);
	return 0;
}
